@@ -1,6 +1,6 @@
 NAMESPACE <- environment()
 # this is replace by the true module later
-module <- new( "Module" )
+module <- Module("highlight")
 
 .onAttach <- function( libname, pkgname ){
 	options( detective = simple_detective )
@@ -11,10 +11,6 @@ module <- new( "Module" )
 	}
 	.findExternalHighlight()
 	
-	unlockBinding( "module", NAMESPACE )
-	assign( "module", Module("highlight"), NAMESPACE )
-	lockBinding( "module", NAMESPACE )
-	
 	module$set_data_path( system.file( "highlight", package = "highlight" ) )
 }
 
